"""Top-level package for comorbidipy."""

__author__ = """vvcb"""
__email__ = 'vvcb.n1@gmail.com'
__version__ = '0.4.4'

from .calculator import comorbidity, hfrs, disability
from .colnames import get_colnames